@@ -15,7 +15,8 @@ from ..task import TaskManager
 log = logging.getLogger(__name__)
 
 TypeEventHandler = Callable[['Bot', Event], Coroutine]
-MessageHandler = Callable[[Message], Coroutine]
+TypeMessageHandler = Callable[[Message], Coroutine]
+TypeStartupHandler = Callable[['Bot'], Coroutine]
 
 
 class Bot(AsyncRunnable):
@@ -34,6 +35,8 @@ class Bot(AsyncRunnable):
     _me: Optional[User]
     _event_index: Dict[EventTypes, List[TypeEventHandler]]
 
+    _startup_index: List[TypeStartupHandler]
+
     def __init__(self,
                  token: str = '',
                  *,
@@ -59,19 +62,17 @@ class Bot(AsyncRunnable):
         """
         if not token and not cert:
             raise ValueError('require token or cert')
+
         self._init_client(cert or Cert(token=token), client, gate, out, compress, port, route)
-        msg_handler = self._make_msg_handler()
-        self.client.register(MessageTypes.TEXT, msg_handler)
-        self.client.register(MessageTypes.KMD, msg_handler)
-        self.client.register(MessageTypes.SYS, self._make_event_handler())
+        self._register_client_handler()
 
         self.command = CommandManager()
+
         self.task = TaskManager()
 
         self._is_running = False
-
         self._event_index = {}
-        self._tasks = []
+        self._startup_index = []
 
     def _init_client(self, cert: Cert, client: Client, gate: Gateway, out: HTTPRequester, compress: bool, port, route):
         """
@@ -107,6 +108,15 @@ class Bot(AsyncRunnable):
 
         self.client = Client(Gateway(_out, _in))
 
+    def _register_client_handler(self):
+        # text and kmd -> msg
+        msg_handler = self._make_msg_handler()
+        self.client.register(MessageTypes.TEXT, msg_handler)
+        self.client.register(MessageTypes.KMD, msg_handler)
+
+        # sys -> event
+        self.client.register(MessageTypes.SYS, self._make_event_handler())
+
     def _make_msg_handler(self) -> Callable:
         """
         construct a function to receive msg from client, and interpret it with _cmd_index
@@ -137,7 +147,7 @@ class Bot(AsyncRunnable):
         log.debug(f'event_handler {handler.__qualname__} for {type} added')
         return handler
 
-    def add_message_handler(self, handler: MessageHandler, *except_type: MessageTypes):
+    def add_message_handler(self, handler: TypeMessageHandler, *except_type: MessageTypes):
         """`except_type` is an exclusion list"""
         for type in MessageTypes:
             if type not in except_type:
@@ -157,11 +167,18 @@ class Bot(AsyncRunnable):
         :param except_type: excepted types
         """
 
-        def dec(func: MessageHandler):
+        def dec(func: TypeMessageHandler):
             self.add_message_handler(func, *set(except_type + (MessageTypes.SYS, )))
 
         return dec
 
+    def on_startup(self, func: TypeStartupHandler):
+        """decorator, register a function to handle bot start"""
+
+        self._startup_index.append(func)
+
+        return func
+
     async def fetch_me(self, force_update: bool = False) -> User:
         """fetch detail of the bot it self as a ``User``
 
@@ -448,6 +465,8 @@ class Bot(AsyncRunnable):
         await self.client.update_channel(channel, name, topic, slow_mode)
 
     async def start(self):
+        for func in self._startup_index:
+            await func(self)
         if self._is_running:
             raise RuntimeError('this bot is already running')
         self.task.schedule()
