@@ -1,32 +1,39 @@
+"""components in Element category"""
 from typing import Union, Dict
 
-from .interface import Types, _Element
+from .interface import Types, _Common
 
 
 class Element:
+    """components in Element category
 
-    class Text(_Element):
+    the most basic content delivers, usually contained in module"""
+
+    class Text(_Common):
+        """Text Element"""
         content: str
         emoji: bool
 
-        def __init__(self, content: str, type: Union[Types.Text, str] = Types.Text.PLAIN, emoji: bool = True):
-            if isinstance(type, str):
-                type = Types.Text(type)  # check if type in Type.Text
-            self._type = type.value
+        def __init__(self, content: str, text_type: Union[Types.Text, str] = Types.Text.PLAIN, emoji: bool = True):
+            if isinstance(text_type, str):
+                text_type = Types.Text(text_type)  # check if type in Type.Text
+            self._type = text_type.value
             self.content = content
             self.emoji = emoji
             super().__init__(Types.Theme.NA, Types.Size.NA)
 
         @property
         def _repr(self) -> Union[Dict, str]:
-            if self._type == Types.Text.PLAIN.value and self.emoji:  # 「为了方便书写，所有plain-text的使用处可以简单的用字符串代替。」
+            # 「为了方便书写，所有plain-text的使用处可以简单的用字符串代替。」
+            if self._type == Types.Text.PLAIN.value and self.emoji:
                 return self.content
-            d = self._gen_dict(['type', 'content'])
+            result = self._gen_dict(['type', 'content'])
             if self._type == Types.Text.PLAIN.value:
-                d['emoji'] = self.emoji
-            return d
+                result['emoji'] = self.emoji
+            return result
 
-    class Image(_Element):
+    class Image(_Common):
+        """Image Element"""
         _type = 'image'
         src: str
         alt: str
@@ -44,7 +51,10 @@ class Element:
         def _repr(self) -> Dict:
             return self._gen_dict(['type', 'src', 'alt', 'size', 'circle'])
 
-    class Button(_Element):
+    class Button(_Common):
+        """Button Element
+
+        can react to user's click"""
         _type = 'button'
         _click: Types.Click
         text: 'Element.Text'
@@ -62,6 +72,13 @@ class Element:
 
         @property
         def click(self) -> str:
+            """there is two types of actions for button to react when user clicks, which depends on the `Button.click`:
+
+            1. `Button.click` == Types.Click.RETURN_VAL:
+            returns the `Button.value` back to bot
+
+            2. `Button.click` == Types.Click.LINK:
+            khl client will open a browser tab for user, with link = `Button.value`"""
             return self._click.value
 
         @click.setter
