@@ -11,8 +11,10 @@ _RE_INVITE_LINK = re.compile(r'^https://kaihei\.co/[a-zA-Z0-9]{6}$')
 
 
 class Module:
+    """docs: https://github.com/kaiheila/api-docs/blob/main/docs/zh-cn/cardmessage.md#%E6%A8%A1%E5%9D%97"""
 
     class Header(_Module):
+        """please refer to module docs"""
         _type = 'header'
         _text: Element.Text
 
@@ -22,6 +24,7 @@ class Module:
 
         @property
         def text(self) -> Element.Text:
+            """contained text"""
             return self._text
 
         @text.setter
@@ -33,6 +36,7 @@ class Module:
             return self._gen_dict(['type', 'text'])
 
     class Section(_Module):
+        """docs: https://t.ly/uM4K"""
         _type = 'section'
         _text: Element.Text
         _accessory: Union[Element.Image, Element.Button, None]
@@ -49,6 +53,7 @@ class Module:
 
         @property
         def text(self) -> Element.Text:
+            """contained text"""
             return self._text
 
         @text.setter
@@ -57,6 +62,7 @@ class Module:
 
         @property
         def mode(self) -> Types.SectionMode:
+            """the section's mode, refet to SectionMode for enum detail"""
             return self._mode
 
         @mode.setter
@@ -65,6 +71,7 @@ class Module:
 
         @property
         def accessory(self) -> Union[Element.Image, Element.Button]:
+            """the accessory attached to the section, a button/an image"""
             return self._accessory
 
         @accessory.setter
@@ -78,6 +85,7 @@ class Module:
             return self._gen_dict(['type', 'text', 'mode', 'accessory'])
 
     class ImageGroup(_Module):
+        """docs: https://t.ly/2yaa"""
         _type = 'image-group'
         _elements: List[Element.Image]
 
@@ -88,16 +96,19 @@ class Module:
             super().__init__(Types.Theme.NA, Types.Size.NA)
 
         def append(self, image: Element.Image):
+            """append a image into"""
             if len(self._elements) >= 9:
                 raise ValueError('element max length exceeded(9)')
             self._elements.append(image)
 
-        def pop(self, index: int):
+        def pop(self, index: int = ...):
+            """pop a image from"""
             if len(self._elements) <= 1:
                 raise ValueError('element min length exceeded(1)')
             return self._elements.pop(index)
 
         def len(self) -> int:
+            """count of current elements"""
             return len(self._elements)
 
         @property
@@ -105,6 +116,9 @@ class Module:
             return self._gen_dict(['type', 'elements'])
 
     class ActionGroup(_Module):
+        """a group of buttons(now only support buttons)
+
+        docs: https://t.ly/LBVJ"""
         _type = 'action-group'
         _elements: List[Element.Button]
 
@@ -113,9 +127,11 @@ class Module:
             super().__init__(Types.Theme.NA, Types.Size.NA)
 
         def append(self, element: Element.Button):
+            """append a button into"""
             self._elements.append(element)
 
         def pop(self, index: int = None) -> Element.Button:
+            """pop a button from"""
             return self._elements.pop(index)
 
         @property
@@ -123,6 +139,9 @@ class Module:
             return self._gen_dict(['type', 'elements'])
 
     class Context(_Module):
+        """a set of text/images
+
+        docs: https://t.ly/_ECm"""
         _type = 'context'
         _elements: List[Union[Element.Text, Element.Image]]
 
@@ -131,9 +150,11 @@ class Module:
             super().__init__(Types.Theme.NA, Types.Size.NA)
 
         def append(self, element: Union[Element.Text, Element.Image, str]):
+            """append a text/image into"""
             self._elements.append(Element.Text(element) if isinstance(element, str) else element)
 
         def pop(self, index: int = None):
+            """pop a text/image from"""
             return self._elements.pop(index)
 
         @property
@@ -141,6 +162,7 @@ class Module:
             return self._gen_dict(['type', 'elements'])
 
     class Divider(_Module):
+        """docs: https://t.ly/vpuy"""
         _type = 'divider'
 
         def __init__(self):
@@ -151,9 +173,12 @@ class Module:
             return {'type': 'divider'}
 
     class Invite(_Module):
+        """component to invite others to a server
+
+        docs: https://t.ly/q-5V"""
         _type = 'invite'
 
-        def __init__(self, code: str=''):
+        def __init__(self, code: str = ''):
             if _RE_INVITE_CODE.match(code) or _RE_INVITE_LINK.match(code):
                 self._code = code
             else:
@@ -162,6 +187,7 @@ class Module:
 
         @property
         def code(self) -> str:
+            """invite code"""
             return self._code
 
         @code.setter
@@ -176,14 +202,15 @@ class Module:
             return self._gen_dict(['type', 'code'])
 
     class File(_Module):
+        """show file in a module
+
+        docs: https://t.ly/U9tm"""
         src: str
         title: str
         cover: str
 
         def __init__(self, type: Union[Types.File, str], src: str, title: str = '', cover: str = ''):
-            if isinstance(type, str):
-                type = Types.File(type)  # check if type in Type.File
-            self._type = type.value
+            self._type = type.value if isinstance(type, Types.File) else type
             self.src = src
             self.title = title
             self.cover = cover
@@ -197,6 +224,9 @@ class Module:
             return d
 
     class Countdown(_Module):
+        """count down module
+
+        docs: https://t.ly/Xwtp"""
         _type = "countdown"
         end: datetime.datetime
         mode: Types.CountdownMode
@@ -220,33 +250,8 @@ class Module:
             d['endTime'] = int(self.end.timestamp() * 1000)
             return d
 
-    class Container(_Module):
-        # 除_type和ImageGroup不一样 其余完全一致
-        # class Container(ImageGroup):
-        #     _type = 'container'
-        # 偷懒一点这样也没什么问题(
+    class Container(ImageGroup):
+        """contains images, like image-group but the images are not stripped into square
+
+        docs: https://t.ly/Rpn6"""
         _type = 'container'
-        _elements: List[Element.Image]
-
-        def __init__(self, *images: Element.Image):
-            if not 1 <= len(images) <= 9:
-                raise ValueError('element length unacceptable, should: 9 >= len >= 1')
-            self._elements = list(images)
-            super().__init__(Types.Theme.NA, Types.Size.NA)
-
-        def append(self, image: Element.Image):
-            if len(self._elements) >= 9:
-                raise ValueError('element max length exceeded(9)')
-            self._elements.append(image)
-
-        def pop(self, index: int):
-            if len(self._elements) <= 1:
-                raise ValueError('element min length exceeded(1)')
-            return self._elements.pop(index)
-
-        def len(self) -> int:
-            return len(self._elements)
-
-        @property
-        def _repr(self) -> Union[Dict, str]:
-            return self._gen_dict(['type', 'elements'])
